# Text support

![Build status](https://travis-ci.com/musket-ml/musket_text.svg?branch=master)

This package adds text-related datasets, preprocessors and algorithms 
(like BERT) to [Generic pipeline](https://github.com/musket-ml/musket_core) of [Musket ML](https://musket-ml.com/).

## Installation

```
pip install musket_text
```

This package is a part of [Musket ML](https://musket-ml.com/) framework,
 it is recommended to install the whole collection of the framework
 packages at once using instructions [here](https://musket-ml.github.io/webdocs/generic/#installation).

